import subprocess
import json
import os

def start_training(
    model_path,
    dataset_path,
    recipe_path,
    recipe_id,
    recipe_revision,
    run_path,
    client_params,
    adapter_name,
):
    """
    Start a DeepSpeed training process with the given parameters.
    Returns the process return code.
    """
    run_file_path = os.path.join(os.path.dirname(__file__), "run.py")

    # Build command with all required arguments
    command = [
        "deepspeed",
        run_file_path,
        "--model_path", model_path,
        "--dataset_path", dataset_path,
        "--recipe_path", recipe_path,
        "--run_path", run_path,
        "--client_params", json.dumps(client_params),
        "--adapter_name", adapter_name,
        "--recipe_id", recipe_id,
        "--recipe_revision", recipe_revision,
    ]

    # Run process with real-time output streaming
    process = subprocess.Popen(
        command,
        env={**os.environ, "PYTHONUNBUFFERED": "1"},
        text=True,
        bufsize=1,
        stdout=subprocess.PIPE,
        stderr=subprocess.STDOUT,
    )

    # Stream output in real-time
    for line in process.stdout:
        print(line, end='', flush=True)
    
    process.wait()
    return process.returncode